@@ -1,10 +1,15 @@
 from six import with_metaclass
+import threading
+
 from pluggy import PluginManager
 from allure_commons import _hooks
-import allure_commons
+
 import pytest
 from allure_pytest.helper import AllureTitleHelper
-
+from allure_pytest.listener import AllureListener
+from allure_commons.reporter import AllureReporter
+import allure_pytest
+import allure_commons
 
 class MetaPluginManager(type):
     @staticmethod
@@ -26,6 +31,16 @@ class plugin_manager(with_metaclass(MetaPluginManager)):
     pass
 
 
+class ThreadLocalAllureListener(threading.local, AllureListener):
+    def __init__(self,config):
+        super(ThreadLocalAllureListener, self).__init__(config)
+
+
+class ThreadLocalAllureReporter(threading.local, AllureReporter):
+    def __init__(self):
+        super(ThreadLocalAllureReporter, self).__init__()
+
+
 @pytest.mark.tryfirst
 def pytest_configure(config):
     title_helper = AllureTitleHelper()
@@ -34,4 +49,7 @@ def pytest_configure(config):
     allure_commons.plugin_manager = plugin_manager
     allure_commons._core.plugin_manager = plugin_manager
     allure_commons.reporter.plugin_manager = plugin_manager
-    allure_commons._allure.plugin_manager = plugin_manager
\ No newline at end of file
+    allure_commons._allure.plugin_manager = plugin_manager
+
+    allure_pytest.plugin.AllureReporter = ThreadLocalAllureReporter
+    allure_pytest.plugin.AllureListener = ThreadLocalAllureListener
\ No newline at end of file
